# frozen_string_literal: true

require "test_helper"

module Hrb
  class TemplateTest < Minitest::Test
    def test_render
      assert rendered.css("#test > #top + #content").size == 1
      assert rendered.css("#content > p").size == 2
    end

    def test_locals
      html = Oga.parse_html(Hrb::Template.render(locals: {name: "Evan", date: "2019-06-17"}) do
        strong("Hi, I am #{name}")
        small("The date is #{date}")
      end)

      assert_equal "Hi, I am Evan", html.css("strong").text
      assert_equal "The date is 2019-06-17", html.css("small").text
    end

    def test_scope
      html = Oga.parse_html(Hrb::Template.render(scope: scope) do
        h1("Hi, I am #{name}")
        h2("The date is #{date}")
      end)

      assert_equal "Hi, I am Evan", html.css("h1").text
      assert_equal "The date is 2019-06-17", html.css("h2").text
    end

    def test_to_s
      template = Hrb::Template.new
      template.instance_eval do
        div("Hello!")
      end

      assert_equal "<div>Hello!</div>", template.to_s
    end

    private

    Scope = Struct.new(:name, :date)

    def scope
      Scope.new("Evan", "2019-06-17")
    end

    # rubocop:disable Metrics/MethodLength
    def rendered
      Oga.parse_html(Hrb::Template.render do
        div(id: "test") do
          header(id: "top") do
            h1("Hrb is HTML in Ruby")
          end
          main(id: "content") do
            p("It's not a new idea, but it's neat.")
            p("I hope you like it.")
          end
        end
      end)
    end
  end
  # rubocop:enable Metrics/MethodLength
end
